@@ -8,7 +8,6 @@ use std::fs::{create_dir_all, File, OpenOptions};
 use std::io::BufRead;
 use std::io::BufReader;
 use std::io::Write;
-use std::iter::FromIterator;
 use std::path::{Path, PathBuf};
 use std::sync::RwLock;
 
@@ -161,15 +160,7 @@ impl EventDatabase {
 
         let mut ping_sent = false;
         for store_name in store_names {
-            if let Err(err) = glean.submit_ping_by_name(&store_name, Some("startup")) {
-                log::warn!(
-                    "Error flushing existing events to the '{}' ping: {}",
-                    store_name,
-                    err
-                );
-            } else {
-                ping_sent = true;
-            }
+            ping_sent |= glean.submit_ping_by_name(&store_name, Some("startup"));
         }
 
         ping_sent
@@ -217,7 +208,7 @@ impl EventDatabase {
                 store.push(event.clone());
                 self.write_event_to_disk(store_name, &event_json);
                 if store.len() == glean.get_max_events() {
-                    stores_to_submit.push(&store_name);
+                    stores_to_submit.push(store_name);
                 }
             }
         }
@@ -225,14 +216,7 @@ impl EventDatabase {
         // If any of the event stores reached maximum size, submit the pings
         // containing those events immediately.
         for store_name in stores_to_submit {
-            if let Err(err) = glean.submit_ping_by_name(store_name, Some("max_capacity")) {
-                log::warn!(
-                    "Got more than {} events, but could not persist {} ping: {}",
-                    glean.get_max_events(),
-                    store_name,
-                    err
-                );
-            }
+            glean.submit_ping_by_name(store_name, Some("max_capacity"));
         }
     }
 
@@ -277,9 +261,11 @@ impl EventDatabase {
                     // in a single location.
                     store.sort_by(|a, b| a.timestamp.cmp(&b.timestamp));
                     let first_timestamp = store[0].timestamp;
-                    Some(JsonValue::from_iter(
-                        store.iter().map(|e| e.serialize_relative(first_timestamp)),
-                    ))
+                    let snapshot = store
+                        .iter()
+                        .map(|e| e.serialize_relative(first_timestamp))
+                        .collect();
+                    Some(snapshot)
                 } else {
                     log::warn!("Unexpectly got empty event store for '{}'", store_name);
                     None
@@ -380,7 +366,7 @@ mod test {
         let t = tempfile::tempdir().unwrap();
 
         {
-            let db = EventDatabase::new(&t.path()).unwrap();
+            let db = EventDatabase::new(t.path()).unwrap();
             db.write_event_to_disk("events", "{\"timestamp\": 500");
             db.write_event_to_disk("events", "{\"timestamp\"");
             db.write_event_to_disk(
@@ -390,7 +376,7 @@ mod test {
         }
 
         {
-            let db = EventDatabase::new(&t.path()).unwrap();
+            let db = EventDatabase::new(t.path()).unwrap();
             db.load_events_from_disk().unwrap();
             let events = &db.event_stores.read().unwrap()["events"];
             assert_eq!(1, events.len());
@@ -462,11 +448,8 @@ mod test {
             extra: Some(data),
         };
 
-        assert_eq!(
-            event_empty,
-            serde_json::from_str(&event_empty_json).unwrap()
-        );
-        assert_eq!(event_data, serde_json::from_str(&event_data_json).unwrap());
+        assert_eq!(event_empty, serde_json::from_str(event_empty_json).unwrap());
+        assert_eq!(event_data, serde_json::from_str(event_data_json).unwrap());
     }
 
     #[test]
